PagedValue<Key, Value> class sealed

Paged value that can be used with PagedValueNotifier.

Annotations
  • @freezed

Constructors

PagedValue({required List<Value> items, Key? nextPageKey, StreamChatError? error})
Represents the success state of the PagedValue
const
factory
PagedValue.error(StreamChatError error)
Represents the error state of the PagedValue.
const
factory
PagedValue.loading()
Represents the loading state of the PagedValue.
const
factory

Properties

asSuccess → Success<Key, Value>
Returns the PagedValue as Success.
no setter
hasError bool
Returns true if the PagedValue is Success and has an error.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasNextPage bool
Returns true if the PagedValue is Success and has more items to load.
no setter
isNotSuccess bool
Returns true if the PagedValue is not Success.
no setter
isSuccess bool
Returns true if the PagedValue is Success.
no setter
itemCount int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited