StreamMessageSearchListController class
A controller for a message search list.
This class lets you perform tasks such as:
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
PagedValue< String, GetMessageResponse> > - PagedValueNotifier<
String, GetMessageResponse> - StreamMessageSearchListController
Constructors
-
StreamMessageSearchListController({required StreamChatClient client, required Filter filter, Filter? messageFilter, String? searchQuery, SortOrder<
ComparableFieldProvider> ? sort, int limit = defaultMessageSearchPagedLimit}) - Creates a Stream message search list controller.
-
StreamMessageSearchListController.fromValue(PagedValue<
String, GetMessageResponse> value, {required StreamChatClient client, required Filter filter, Filter? messageFilter, String? searchQuery, SortOrder<ComparableFieldProvider> ? sort, int limit = defaultMessageSearchPagedLimit}) -
Creates a StreamMessageSearchListController from the passed
value.
Properties
- client → StreamChatClient
-
The client to use for the message search.
final
-
currentItems
→ List<
GetMessageResponse> -
Returns the currently loaded items
no setterinherited
- debouncePolicy → SearchDebouncePolicy
-
The policy driving
debouncedSearch's length-based delays.no setterinherited - disposed → bool
-
Whether dispose has been called on this notifier.
no setterinherited
- filter ↔ Filter
-
Allows for the change of filters used for message search queries.
finalgetter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- limit → int
-
The limit to apply to the message search. The default is set to
defaultMessageSearchPagedLimit.
final
- messageFilter ↔ Filter?
-
Allows for the change of message filters used for message search queries.
finalgetter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchQuery ↔ String?
-
Allows for the change of filters used for message search queries.
finalgetter/setter pair
-
sort
↔ SortOrder<
ComparableFieldProvider> ? -
Allows for the change of the query sort used for message search queries.
finalgetter/setter pair
-
value
↔ PagedValue<
String, GetMessageResponse> -
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
appendLastPage(
List< GetMessageResponse> newItems) → void -
Appends
newItemsto the previously loaded ones and sets the next page key tonull.inherited -
appendPage(
{required List< GetMessageResponse> newItems, required String nextPageKey}) → void -
Appends
newItemsto the previously loaded ones and replaces the next page's key.inherited -
clearResults(
) → void -
Cancels any pending search, invalidates in-flight loads, and clears the
current results.
inherited
-
dispose(
) → void -
Cancels any pending debounced search before disposing the notifier.
inherited
-
doInitialLoad(
) → Future< void> -
Load initial data from the server.
override
-
loadMore(
String nextPageKey) → Future< void> -
Load more data from the server using
nextPageKey.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
refresh(
{bool resetValue = true}) → Future< void> -
Refresh the data presented by this PagedValueNotifier.
override
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
retry(
) → Future< void> -
Retry any failed load requests.
inherited
-
search(
String query) → void -
Searches messages whose text matches
query, debounced by its length. -
searchWithFilter(
Filter filter) → void -
Searches with an explicit message
filter, debounced by the search text it holds. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited