debouncePolicy property
The policy driving debouncedSearch's length-based delays.
Override to tune the delays for a particular list.
Implementation
@protected
SearchDebouncePolicy get debouncePolicy => const SearchDebouncePolicy();
The policy driving debouncedSearch's length-based delays.
Override to tune the delays for a particular list.
@protected
SearchDebouncePolicy get debouncePolicy => const SearchDebouncePolicy();