searchQuery property

String? get searchQuery

Allows for the change of filters used for message search queries.

Use this if you need to support runtime filter changes, through custom filters UI.

Note: This will not trigger a new query. make sure to call doInitialLoad after setting a new filter.

Implementation

final String? searchQuery;
set searchQuery (String? value)

Allows for the change of filters used for message search queries.

Use this if you need to support runtime filter changes, through custom filters UI.

Note: This will not trigger a new query. make sure to call doInitialLoad after setting a new filter.

Implementation

set searchQuery(String? value) => _activeSearchQuery = value;