messageFilter property
Filter?
get
messageFilter
Allows for the change of message filters used for message search queries.
Use this if you need to support runtime filter changes, through custom filters UI.
Note: This will not trigger a new query. make sure to call doInitialLoad after setting a new filter.
Implementation
final Filter? messageFilter;
set
messageFilter
(Filter? value)
Allows for the change of message filters used for message search queries.
Use this if you need to support runtime filter changes, through custom filters UI.
Note: This will not trigger a new query. make sure to call doInitialLoad after setting a new filter.
Implementation
set messageFilter(Filter? value) => _activeMessageFilter = value;