sort property
SortOrder<ComparableFieldProvider> ?
get
sort
Allows for the change of the query sort used for message search queries.
Use this if you need to support runtime sort changes, through custom sort UI.
Note: This will not trigger a new query. make sure to call doInitialLoad after setting a new sort.
Implementation
final SortOrder? sort;
set
sort
(SortOrder<ComparableFieldProvider> ? value)
Allows for the change of the query sort used for message search queries.
Use this if you need to support runtime sort changes, through custom sort UI.
Note: This will not trigger a new query. make sure to call doInitialLoad after setting a new sort.
Implementation
set sort(SortOrder? value) => _activeSort = value;